@@ -235,6 +235,15 @@ namespace PyDeviceImpl
         attr.fire_change_event();
     }
 
+    // Special variantion for encoded data type
+    inline void push_change_event(Tango::DeviceImpl &self, str &name, str &str_data,
+                                  object &data)
+    {
+        SAFE_PUSH(self, attr, name)
+        PyAttribute::set_value(attr, str_data, data);
+        attr.fire_change_event();
+    }
+
     inline void push_change_event(Tango::DeviceImpl &self, str &name, object &data,
                                   long x)
     {
@@ -266,6 +275,15 @@ namespace PyDeviceImpl
         attr.fire_change_event();
     }
 
+    // Special variantion for encoded data type
+    inline void push_change_event(Tango::DeviceImpl &self, str &name, str &str_data,
+                                  object &data, double t, Tango::AttrQuality quality)
+    {
+        SAFE_PUSH(self, attr, name)
+        PyAttribute::set_value_date_quality(attr, str_data, data, t, quality);
+        attr.fire_change_event();
+    }
+
     inline void push_change_event(Tango::DeviceImpl &self, str &name, object &data,
                                   double t, Tango::AttrQuality quality, long x)
     {
@@ -299,7 +317,7 @@ namespace PyDeviceImpl
         SAFE_PUSH_ARCHIVE_EVENT(self, name, data);
     }
 
-    // Special variantion for encoded data type
+    // Special variation for encoded data type
     inline void push_archive_event(Tango::DeviceImpl &self, str &name, str &str_data,
                                    str &data)
     {
@@ -308,6 +326,15 @@ namespace PyDeviceImpl
         attr.fire_archive_event();
     }
 
+    // Special variation for encoded data type
+    inline void push_archive_event(Tango::DeviceImpl &self, str &name, str &str_data,
+                                   object &data)
+    {
+        SAFE_PUSH(self, attr, name)
+        PyAttribute::set_value(attr, str_data, data);
+        attr.fire_archive_event();
+    }
+
     inline void push_archive_event(Tango::DeviceImpl &self, str &name, object &data,
                            long x)
     {
@@ -339,6 +366,15 @@ namespace PyDeviceImpl
         attr.fire_archive_event();
     }
 
+    // Special variantion for encoded data type
+    inline void push_archive_event(Tango::DeviceImpl &self, str &name, str &str_data,
+                                   object &data, double t, Tango::AttrQuality quality)
+    {
+        SAFE_PUSH(self, attr, name)
+        PyAttribute::set_value_date_quality(attr, str_data, data, t, quality);
+        attr.fire_archive_event();
+    }
+
     inline void push_archive_event(Tango::DeviceImpl &self, str &name, object &data,
                                   double t, Tango::AttrQuality quality, long x)
     {
@@ -377,6 +413,16 @@ namespace PyDeviceImpl
         attr.fire_event(filt_names_, filt_vals_);
     }
 
+    // Special variantion for encoded data type
+    inline void push_event(Tango::DeviceImpl &self, str &name,
+                           object &filt_names, object &filt_vals,
+                           str &str_data, object &data)
+    {
+        AUX_SAFE_PUSH_EVENT(self, name, filt_names, filt_vals)
+        PyAttribute::set_value(attr, str_data, data);
+        attr.fire_event(filt_names_, filt_vals_);
+    }
+
     inline void push_event(Tango::DeviceImpl &self, str &name,
                            object &filt_names, object &filt_vals, object &data,
                            long x)
@@ -413,6 +459,17 @@ namespace PyDeviceImpl
         attr.fire_event(filt_names_, filt_vals_);
     }
 
+    // Special variantion for encoded data type
+    inline void push_event(Tango::DeviceImpl &self, str &name,
+                           object &filt_names, object &filt_vals,
+                           str &str_data, object &data,
+                           double t, Tango::AttrQuality quality)
+    {
+        AUX_SAFE_PUSH_EVENT(self, name, filt_names, filt_vals)
+        PyAttribute::set_value_date_quality(attr, str_data, data, t, quality);
+        attr.fire_event(filt_names_, filt_vals_);
+    }
+
     inline void push_event(Tango::DeviceImpl &self, str &name,
                            object &filt_names, object &filt_vals, object &data,
                            double t, Tango::AttrQuality quality, long x)
@@ -1254,6 +1311,10 @@ void export_device_impl()
             (void (*) (Tango::DeviceImpl &, str &, str &, str &))
             &PyDeviceImpl::push_change_event)
 
+        .def("push_change_event",
+            (void (*) (Tango::DeviceImpl &, str &, str &, object &))
+            &PyDeviceImpl::push_change_event)
+
         .def("push_change_event",
             (void (*) (Tango::DeviceImpl &, str &, object &, long))
             &PyDeviceImpl::push_change_event)
@@ -1270,6 +1331,10 @@ void export_device_impl()
             (void (*) (Tango::DeviceImpl &, str &, str &, str &, double, Tango::AttrQuality))
             &PyDeviceImpl::push_change_event)
 
+        .def("push_change_event",
+            (void (*) (Tango::DeviceImpl &, str &, str &, object &, double, Tango::AttrQuality))
+            &PyDeviceImpl::push_change_event)
+
         .def("push_change_event",
             (void (*) (Tango::DeviceImpl &, str &, object &, double, Tango::AttrQuality, long))
             &PyDeviceImpl::push_change_event)
@@ -1291,6 +1356,10 @@ void export_device_impl()
             (void (*) (Tango::DeviceImpl &, str &, str &, str &))
             &PyDeviceImpl::push_archive_event)
 
+        .def("push_archive_event",
+            (void (*) (Tango::DeviceImpl &, str &, str &, object &))
+            &PyDeviceImpl::push_archive_event)
+
         .def("push_archive_event",
             (void (*) (Tango::DeviceImpl &, str &, object &, long))
             &PyDeviceImpl::push_archive_event)
@@ -1307,6 +1376,10 @@ void export_device_impl()
             (void (*) (Tango::DeviceImpl &, str &, str &, str &, double, Tango::AttrQuality))
             &PyDeviceImpl::push_archive_event)
 
+        .def("push_archive_event",
+            (void (*) (Tango::DeviceImpl &, str &, str &, object &, double, Tango::AttrQuality))
+            &PyDeviceImpl::push_archive_event)
+
         .def("push_archive_event",
             (void (*) (Tango::DeviceImpl &, str &, object &, double, Tango::AttrQuality, long))
             &PyDeviceImpl::push_archive_event)
@@ -1327,6 +1400,10 @@ void export_device_impl()
             (void (*) (Tango::DeviceImpl &, str &, object &, object &, str &, str &))
             &PyDeviceImpl::push_event)
 
+        .def("push_event",
+            (void (*) (Tango::DeviceImpl &, str &, object &, object &, str &, object &))
+            &PyDeviceImpl::push_event)
+
         .def("push_event",
             (void (*) (Tango::DeviceImpl &, str &, object &, object &, object &, long))
             &PyDeviceImpl::push_event)
@@ -1343,6 +1420,10 @@ void export_device_impl()
             (void (*) (Tango::DeviceImpl &, str &, object &, object &, str &, str &, double, Tango::AttrQuality))
             &PyDeviceImpl::push_event)
 
+        .def("push_event",
+            (void (*) (Tango::DeviceImpl &, str &, object &, object &, str &, object &, double, Tango::AttrQuality))
+            &PyDeviceImpl::push_event)
+
         .def("push_event",
             (void (*) (Tango::DeviceImpl &, str &, object &, object &, object &, double, Tango::AttrQuality, long))
             &PyDeviceImpl::push_event)
