@@ -141,7 +141,7 @@ class AttrData(object):
         p = UserDefaultAttrProp()
 
         doc = extra_info.pop('doc', None)
-        if 'doc' is not None:
+        if doc is not None:
             extra_info['description'] = doc
         
         for k, v in extra_info.items():
@@ -274,8 +274,13 @@ class AttrData(object):
             throw_ex("Wrong polling period in attribute information for "
                      "attribute %s in class %s\nAttribute information for "
                      "polling period is not an integer" % (attr_name, name))
-        
-        memorized = extra_info.get("memorized", "false").lower()
+
+        try:
+            memorized = extra_info.get("memorized", "false").lower()
+        except:
+            throw_ex("Wrong memorized value. for attribute %s in class %s."
+                     "Allowed valued are the strings \"true\", \"false\" and "
+                     "\"true_without_hard_applied\" (case incensitive)")
         if memorized == "true":
             self.memorized = True
             self.hw_memorized = True
