@@ -9,10 +9,7 @@
 # See LICENSE.txt for more info.
 # -----------------------------------------------------------------------------
 
-__all__ = ['load_ipython_extension', 'unload_ipython_extension', 'load_config',
-           'run', 'install', 'is_installed']
+__all__ = ['init_ipython', 'install']
 
-from .ipython_00_11 import load_ipython_extension, unload_ipython_extension, \
-    load_config, run
+from .ipython_00_10 import init_ipython, run
 from .ipy_install import install, is_installed
-
