@@ -53,10 +53,12 @@ def is_installed(ipydir=None, profile='tango'):
 
 def install(ipydir=None, verbose=True, profile='tango'):
     if verbose:
-        out = sys.stdout
+        def out(msg):
+            sys.stdout.write(msg)
+            sys.stdout.flush()
     else:
-        out = io.BytesIO()
-    
+        out = lambda x : None
+            
     ipython_dir = ipydir or get_ipython_dir()
     try:
         p_dir = ProfileDir.find_profile_dir_by_name(ipython_dir, profile)
@@ -71,16 +73,15 @@ def install(ipydir=None, verbose=True, profile='tango'):
     if not create_config:
         return
 
-    out.write("Installing tango extension to ipython... ")
-    out.flush()
+    out("Installing tango extension to ipython... ")
 
     profile = __PROFILE.format(pytangover=PyTango.Release.version,
                                ipyver=IPython.release.version)
     with open(abs_config_file_name, "w") as f:
         f.write(profile)
         f.close()
-    out.write("[DONE]\n\n")
-    out.write("""\
+    out("[DONE]\n\n")
+    out("""\
 To start ipython with tango interface simply type on the command line:
 %% ipython --profile=tango
 
