@@ -20,7 +20,7 @@ __docformat__ = "restructuredtext"
 import os
 import copy
 
-from ._PyTango import _Util, Except, DevFailed, DbDevInfo
+from ._PyTango import Util, Except, DevFailed, DbDevInfo
 from .utils import document_method as __document_method
 #from utils import document_static_method as __document_static_method
 from .globals import class_list, cpp_class_list, get_constructed_classes
@@ -52,22 +52,22 @@ def __Util__get_class_list(self):
 def __Util__create_device(self, klass_name, device_name, alias=None, cb=None):
     """
         create_device(self, klass_name, device_name, alias=None, cb=None) -> None
-        
+
             Creates a new device of the given class in the database, creates a new
             DeviceImpl for it and calls init_device (just like it is done for
             existing devices when the DS starts up)
-    
-            An optional parameter callback is called AFTER the device is 
+
+            An optional parameter callback is called AFTER the device is
             registered in the database and BEFORE the init_device for the
             newly created device is called
-            
+
             Throws PyTango.DevFailed:
                 - the device name exists already or
                 - the given class is not registered for this DS.
                 - the cb is not a callable
-            
+
         New in PyTango 7.1.2
-        
+
         Parameters :
             - klass_name : (str) the device class name
             - device_name : (str) the device name
@@ -77,17 +77,17 @@ def __Util__create_device(self, klass_name, device_name, alias=None, cb=None):
                    device is called. Typically you may want to put device and/or attribute
                    properties in the database here. The callback must receive a parameter:
                    device name (str). Default value is None meaning no callback
-        
+
         Return     : None"""
     if cb is not None and not isinstance(cb, collections.Callable):
         Except.throw_exception("PyAPI_InvalidParameter",
             "The optional cb parameter must be a python callable",
             "Util.create_device")
-    
+
     db = self.get_database()
 
     device_name = __simplify_device_name(device_name)
-    
+
     device_exists = True
     try:
         db.import_device(device_name)
@@ -96,7 +96,7 @@ def __Util__create_device(self, klass_name, device_name, alias=None, cb=None):
 
     # 1 - Make sure device name doesn't exist already in the database
     if device_exists:
-        Except.throw_exception("PyAPI_DeviceAlreadyDefined", 
+        Except.throw_exception("PyAPI_DeviceAlreadyDefined",
             "The device %s is already defined in the database" % device_name,
             "Util.create_device")
 
@@ -109,28 +109,28 @@ def __Util__create_device(self, klass_name, device_name, alias=None, cb=None):
             klass = k
             break
     if klass is None:
-        Except.throw_exception("PyAPI_UnknownDeviceClass", 
+        Except.throw_exception("PyAPI_UnknownDeviceClass",
             "The device class %s could not be found" % klass_name,
             "Util.create_device")
-            
+
     # 3 - Create entry in the database (with alias if necessary)
     dev_info = DbDevInfo()
     dev_info.name = device_name
     dev_info._class = klass_name
     dev_info.server = self.get_ds_name()
-    
+
     db.add_device(dev_info)
-    
+
     if alias is not None:
         db.put_device_alias(device_name, alias)
 
     # from this point on, if anything wrong happens we need to clean the database
     try:
-        # 4 - run the callback which tipically is used to initialize 
+        # 4 - run the callback which tipically is used to initialize
         #     device and/or attribute properties in the database
         if cb is not None:
             cb(device_name)
-            
+
         # 5 - Initialize device object on this server
         k.device_factory([device_name])
     except:
@@ -144,22 +144,22 @@ def __Util__create_device(self, klass_name, device_name, alias=None, cb=None):
 def __Util__delete_device(self, klass_name, device_name):
     """
         delete_device(self, klass_name, device_name) -> None
-        
+
             Deletes an existing device from the database and from this running
             server
-    
+
             Throws PyTango.DevFailed:
                 - the device name doesn't exist in the database
                 - the device name doesn't exist in this DS.
-        
+
         New in PyTango 7.1.2
-        
+
         Parameters :
             - klass_name : (str) the device class name
             - device_name : (str) the device name
-        
+
         Return     : None"""
-        
+
     db = self.get_database()
     device_name = __simplify_device_name(device_name)
     device_exists = True
@@ -170,10 +170,10 @@ def __Util__delete_device(self, klass_name, device_name):
 
     # 1 - Make sure device name exists in the database
     if not device_exists:
-        Except.throw_exception("PyAPI_DeviceNotDefined", 
+        Except.throw_exception("PyAPI_DeviceNotDefined",
             "The device %s is not defined in the database" % device_name,
             "Util.delete_device")
-    
+
     # 2 - Make sure device name is defined in this server
     class_device_name = "%s::%s" % (klass_name, device_name)
     ds = self.get_dserver_device()
@@ -186,94 +186,95 @@ def __Util__delete_device(self, klass_name, device_name):
             device_exists =True
             break
     if not device_exists:
-        Except.throw_exception("PyAPI_DeviceNotDefinedInServer", 
+        Except.throw_exception("PyAPI_DeviceNotDefinedInServer",
             "The device %s is not defined in this server" % class_device_name,
             "Util.delete_device")
-    
+
     db.delete_device(device_name)
-    
+
     dimpl = self.get_device_by_name(device_name)
-    
+
     dc = dimpl.get_device_class()
     dc.device_destroyer(device_name)
 
-def __Util__server_set_event_loop(self, event_loop):
-    self._server_event_loop = event_loop
-    self._server_set_event_loop()
+def __Util__init__(self, args):
+    args = copy.copy(args)
+    args[0] = os.path.splitext(args[0])[0]
+    Util.__init_orig__(self, args)
 
-class Util(_Util):
+def __Util__add_TgClass(self, klass_device_class, klass_device,
+                        device_class_name=None):
+    """Register a new python tango class. Example::
+
+           util.add_TgClass(MotorClass, Motor)
+           util.add_TgClass(MotorClass, Motor, 'Motor') # equivalent to previous line
+
+       .. deprecated:: 7.1.2
+           Use :meth:`PyTango.Util.add_class` instead."""
+    if device_class_name is None:
+        device_class_name = klass_device.__name__
+    class_list.append((klass_device_class, klass_device, device_class_name))
+
+
+def __Util__add_Cpp_TgClass(self, device_class_name, tango_device_class_name):
+    """Register a new C++ tango class.
+
+       If there is a shared library file called MotorClass.so which
+       contains a MotorClass class and a _create_MotorClass_class method. Example::
+
+           util.add_Cpp_TgClass('MotorClass', 'Motor')
+
+       .. note:: the parameter 'device_class_name' must match the shared
+                 library name.
+
+       .. deprecated:: 7.1.2
+           Use :meth:`PyTango.Util.add_class` instead."""
+    cpp_class_list.append((device_class_name, tango_device_class_name))
+
+def __Util__add_class(self, *args, **kwargs):
     """
-        This class is a used to store TANGO device server process data and to
-        provide the user with a set of utilities method.
+        add_class(self, class<DeviceClass>, class<DeviceImpl>, language="python") -> None
 
-        This class is implemented using the singleton design pattern.
-        Therefore a device server process can have only one instance of this
-        class and its constructor is not public. Example::
-            
-            util = PyTango.Util.instance()
-            print(util.get_host_name())"""
+            Register a new tango class ('python' or 'c++').
 
-    def __init__(self, args):
-        args = copy.copy(args)
-        args[0] = os.path.splitext(args[0])[0]
-        _Util.init(args)
-        _Util.init_python()
+            If language is 'python' then args must be the same as
+            :meth:`PyTango.Util.add_TgClass`. Otherwise, args should be the ones
+            in :meth:`PyTango.Util.add_Cpp_TgClass`. Example::
 
-    def add_TgClass(self, klass_device_class, klass_device, device_class_name=None):
-        """Register a new python tango class. Example::
-           
-               util.add_TgClass(MotorClass, Motor)
-               util.add_TgClass(MotorClass, Motor, 'Motor') # equivalent to previous line
-           
-           .. deprecated:: 7.1.2
-               Use :meth:`PyTango.Util.add_class` instead."""
-               
-        if device_class_name is None:
-            device_class_name = klass_device.__name__
-        class_list.append((klass_device_class, klass_device, device_class_name))
+                util.add_class(MotorClass, Motor)
+                util.add_class('CounterClass', 'Counter', language='c++')
 
-
-    def add_Cpp_TgClass(self, device_class_name, tango_device_class_name):
-        """Register a new C++ tango class.
-           
-           If there is a shared library file called MotorClass.so which
-           contains a MotorClass class and a _create_MotorClass_class method. Example::
-           
-               util.add_Cpp_TgClass('MotorClass', 'Motor')
-               
-           .. note:: the parameter 'device_class_name' must match the shared
-                     library name.
-                    
-           .. deprecated:: 7.1.2
-               Use :meth:`PyTango.Util.add_class` instead."""
-        cpp_class_list.append((device_class_name, tango_device_class_name))
-
-    def add_class(self, *args, **kwargs):
-        """
-            add_class(self, args, language="python") -> None
-            
-                Register a new tango class ('python' or 'c++').
-           
-                If language is 'python' then args must be the same as 
-                :meth:`PyTango.Util.add_TgClass`. Otherwise, args should be the ones
-                in :meth:`PyTango.Util.add_Cpp_TgClass`. Example::
-                
-                    util.add_class(MotorClass, Motor)
-                    util.add_class('CounterClass', 'Counter', language='c++')
-           
-            New in PyTango 7.1.2"""
-        language = kwargs.get("language", "python")
-        f = self.add_TgClass
-        if language != "python":
-            f = f = self.add_Cpp_TgClass
-        return f(*args)
+        New in PyTango 7.1.2"""
+    language = kwargs.get("language", "python")
+    f = self.add_TgClass
+    if language != "python":
+        f = f = self.add_Cpp_TgClass
+    return f(*args)
 
 def __init_Util():
-    _Util.get_class_list = __Util__get_class_list
-    _Util.create_device = __Util__create_device
-    _Util.delete_device = __Util__delete_device
+    Util.__init_orig__ = Util.__init__
+    Util.__init__ = __Util__init__
+    Util.add_TgClass = __Util__add_TgClass
+    Util.add_Cpp_TgClass = __Util__add_Cpp_TgClass
+    Util.add_class = __Util__add_class
+    Util.get_class_list = __Util__get_class_list
+    Util.create_device = __Util__create_device
+    Util.delete_device = __Util__delete_device
 
 def __doc_Util():
+
+    Util.__doc__ = """\
+    This class is a used to store TANGO device server process data and to
+    provide the user with a set of utilities method.
+
+    This class is implemented using the singleton design pattern.
+    Therefore a device server process can have only one instance of this
+    class and its constructor is not public. Example::
+
+        util = PyTango.Util.instance()
+            print(util.get_host_name())
+    """
+
     def document_method(method_name, desc, append=True):
         return __document_method(Util, method_name, desc, append)
 
@@ -584,7 +585,7 @@ def __doc_Util():
 
         New in PyTango 8.0.0
     """ )
-            
+
     document_method("get_sub_dev_diag", """
     get_sub_dev_diag(self) -> SubDevDiag
 
@@ -592,7 +593,7 @@ def __doc_Util():
 
         Parameters : None
         Return     : (SubDevDiag) the sub device manager
-        
+
         New in PyTango 7.0.0
     """ )
 
@@ -603,7 +604,7 @@ def __doc_Util():
 
         Parameters : None
         Return     : None
-        
+
         New in PyTango 7.0.0
     """ )
 
@@ -614,7 +615,7 @@ def __doc_Util():
 
         Parameters : None
         Return     : (Database) the database
-        
+
         New in PyTango 7.0.0
     """ )
 
@@ -622,30 +623,30 @@ def __doc_Util():
     unregister_server(self) -> None
 
             Unregister a device server process from the TANGO database.
-            If the database call fails, a message is displayed on the screen 
+            If the database call fails, a message is displayed on the screen
             and the process is aborted
 
         Parameters : None
         Return     : None
-        
+
         New in PyTango 7.0.0
     """ )
-    
+
     document_method("get_device_list_by_class", """
     get_device_list_by_class(self, class_name) -> sequence<DeviceImpl>
 
             Get the list of device references for a given TANGO class.
             Return the list of references for all devices served by one implementation
             of the TANGO device pattern implemented in the process.
-            
+
         Parameters :
             - class_name : (str) The TANGO device class name
-            
+
         Return     : (sequence<DeviceImpl>) The device reference list
-        
+
         New in PyTango 7.0.0
     """ )
-    
+
     document_method("get_device_by_name", """
     get_device_by_name(self, dev_name) -> DeviceImpl
 
@@ -654,10 +655,10 @@ def __doc_Util():
         Parameters :
             - dev_name : (str) The TANGO device name
         Return     : (DeviceImpl) The device reference
-        
+
         New in PyTango 7.0.0
     """ )
-    
+
     document_method("get_dserver_device", """
     get_dserver_device(self) -> DServer
 
@@ -665,33 +666,33 @@ def __doc_Util():
 
         Parameters : None
         Return     : (DServer) A reference to the dserver device
-        
+
         New in PyTango 7.0.0
     """ )
-    
+
     document_method("get_device_list", """
     get_device_list(self) -> sequence<DeviceImpl>
 
             Get device list from name.
             It is possible to use a wild card ('*') in the name parameter
             (e.g. "*", "/tango/tangotest/n*", ...)
-            
+
         Parameters : None
         Return     : (sequence<DeviceImpl>) the list of device objects
-        
+
         New in PyTango 7.0.0
     """ )
-    
+
     document_method("server_set_event_loop", """
     server_set_event_loop(self, event_loop) -> None
-    
+
         This method registers an event loop function in a Tango server.
         This function will be called by the process main thread in an infinite loop
         The process will not use the classical ORB blocking event loop.
         It is the user responsability to code this function in a way that it implements
-        some kind of blocking in order not to load the computer CPU. The following 
+        some kind of blocking in order not to load the computer CPU. The following
         piece of code is an example of how you can use this feature::
-        
+
             _LOOP_NB = 1
             def looping():
                 global _LOOP_NB
@@ -699,10 +700,10 @@ def __doc_Util():
                 time.sleep(0.1)
                 _LOOP_NB += 1
                 return _LOOP_NB > 100
-            
+
             def main():
                 py = PyTango.Util(sys.argv)
-                
+
                 # ...
 
                 U = PyTango.Util.instance()
@@ -712,11 +713,11 @@ def __doc_Util():
 
         Parameters : None
         Return     : None
-        
+
         New in PyTango 8.1.0
     """ )
 
-            
+
 #    document_static_method("init_python", """
 #    init_python() -> None
 #
